@@ -4,10 +4,7 @@ tm1_create_element <- function(tm1_connection,
                             parent = "",
                             weight = 1) {
 
-  tm1_adminhost <- tm1_connection$adminhost
-  tm1_httpport <- tm1_connection$port
   tm1_auth_key <- tm1_connection$key
-  tm1_ssl <- tm1_connection$ssl
   tm1_base_url <- tm1_connection$base_url
 
   # added because some http does not know space
@@ -18,11 +15,6 @@ tm1_create_element <- function(tm1_connection,
 
   if (tm1_get_element(tm1_connection, dimension, element)$index == 0) {
 
-  u1 <- ifelse(tm1_ssl==TRUE, "https://", "http://")
-  u2 <- tm1_adminhost
-  u3 <- ":"
-  u4 <- tm1_httpport
-  u5 <- "/"
   u6 <- "api/v1/Dimensions('"
   u7 <- dimension
   u8 <- "')/Hierarchies('"
@@ -32,7 +24,7 @@ tm1_create_element <- function(tm1_connection,
 
   # url development
 
-  url <- ifelse(tm1_base_url=="", paste0(u1, u2, u3, u4, u5, u6, u7, u8, u9, u10), paste0(tm1_base_url, u6, u7, u8, u9, u10))
+  url <- paste0(tm1_base_url, u6, u7, u8, u9, u10)
   #url = "https://localhost:8881/api/v1/Dimensions('month')/Hierarchies('month')/Elements"
 
   elementbody1 <- "{    \"Name\": \""
@@ -68,20 +60,14 @@ tm1_create_element <- function(tm1_connection,
 
   if (parent != "" &&  length(componentcheckresult) == 0) {
 
-    u1 <- ifelse(tm1_ssl==TRUE, "https://", "http://")
-    u2 <- tm1_adminhost
-    u3 <- ":"
-    u4 <- tm1_httpport
-    u5 <- "/"
     u6 <- "api/v1/Dimensions('"
     u7 <- dimension
     u8 <- "')/Hierarchies('"
     u9 <- dimension
     u10 <- "')/Edges"
 
-
     # url development
-    url <- ifelse(tm1_base_url=="", paste0(u1, u2, u3, u4, u5, u6, u7, u8, u9, u10), paste0(tm1_base_url, u6, u7, u8, u9, u10))
+    url <- paste0(tm1_base_url, u6, u7, u8, u9, u10)
     #url = "https://localhost:8881/api/v1/Dimensions('month')/Hierarchies('month')/Edges"
 
     elementbody1 <- "[ {    \"ParentName\": \" "
